#!/usr/bin/perl

#
# This script searches with PSI-BLAST in a given protein database
# with a query sequence.
#
# Please edit the location of the ncbi bin directory and the location of
# the formatted database.
#
# If the number of available processor cores is < 4 then please also edit
# the threads variable.
#
# The nicelevel can also be adjusted. Default is 19.
#

#
# Martin Heusel
# Institute of Bioinformatics
# Johannes Kepler University Linz
# Austria
# http://www.bioinf.jku.at/
#
# v 1.0 30.07.2008
#
# $Id: search.pl 53 2008-08-06 08:43:28Z mhe $
#

# NCBI Tools directory
$blastdir = "/PATHTONCBI/bin";
#$blastdir = "/system/apps/biosoft/NCBI/ncbi/bin";

# location of database
# UniRef50 is recommended
# http://www.ebi.ac.uk/uniref/
# ftp://ftp.ebi.ac.uk/pub/databases/uniprot/uniref/uniref50/
$db       = "/PATHTO/DB";
#$db       = "/system/user/bioshare/Data/DBs/Protein/UniRef50/uniref50.fasta";


# number of threads for PSI-BLAST
# More than 4 threads are not speeding things up in our experiments
$threads = 4;

# nice level
$nicelevel = 19;


$infile  = shift;
$tmpfile = shift;
$slot    = shift;

if ( ! -x "$blastdir/blastpgp" ) {

    die "blastpgp not found or not executable! Please check blastdir configuration.";

}


if ( ! -e $db ) {

    die "Database $db not found!";

}

open(INF,"<$infile") || die("can not open $infile");

@seq = <INF>;

$to = $#seq + 1;
$to /= 2;

print "$to\n";

seek INF, 0, 0;


for($i = 1; $i <= $to; $i++){

    print "$i $to\n";

    open(TMP,">$tmpfile") || die("$tmpfile $!");

    $nameline=<INF>;
    print TMP "$nameline";
    $aaline=<INF>;
    printf TMP "$aaline";

    close(TMP);

    # first run with 4 iterations output to /dev/null
    $cmd =  "nice -n $nicelevel $blastdir/blastpgp -a $threads -j 4 -b 0 -d $db -i $tmpfile -C psitmp-$slot.chk -o /dev/null";

    system($cmd);

    # last and fith run with output
    $cmd =  "nice -n $nicelevel $blastdir/blastpgp -a $threads -j 1 -R psitmp-$slot.chk -b 10000 -d $db -i $tmpfile -o OUT$slot/blast-$i.out";

    system($cmd);

}

close(INF);
