#!/bin/bash
#
# Extending FASTA sequences with PSI-BLAST searches on a database.
#
# This shell script grabs all FASTA files in a directory and starts
# a perl script which extends each sequence with PSI-BLAST searches.
#
# The first parameter of the script is the directory of the FASTA files.
#
# It's possible to start several runs in parallel on multi-core multi-processor
# systems. For every run a slot number should be given as a parameter
#
# e.g.
#
# sh sh/extend.sh /dirto/fastafiles 1
#
# The extended sequences are stored in the EXTENDED directory
#
# The extended sequences of one FASTA file are filtered out of duplicates.
#
# Note:
# The original sequences are added to the extended sequences.
#

#
# Martin Heusel
# Institute of Bioinformatics
# Johannes Kepler University Linz
# Austria
# http://www.bioinf.jku.at/
#
# v 1.0 30.07.2008
#
# $Id: extend.sh 43 2008-08-04 16:41:42Z mhe $
#

if [ $# -ne 2 ]; then  # We need parameters
  echo "usage: $0 dirtofastafiles slotnumber"
  exit -1
fi

datadir=$1

slot=$2

if [ ! -d $datadir ]; then
    echo "FASTA directory does not exist!"
    echo "usage: $0 dirtofastafiles slotnumber"
    exit -1
fi

for fasta in $datadir/*.fasta; do
    tmp=${fasta##*/*/}
    id=${tmp%.fasta}
    echo $id
    if [ -e OUT/$slot/blast-1.out ]; then
        rm OUT$slot/*.out
    fi
    if [ ! -e EXTENDED/$id.fasta ]; then
        touch EXTENDED/$id.fasta
        perl perl/search.pl $fasta tmp$slot.fasta $slot
        cd OUT$slot
        for i in blast-*.out; do
            perl ../perl/extractAlignmentsFromBlastout.pl $i >> ../EXTENDED/$id.fasta
        done
        cd ../EXTENDED
        # add original sequences to the extended sequences
        cat ../$fasta >> $id.fasta
        # remove duplicates
        perl ../perl/findDupSeqs.pl $id.fasta > tmp.$id.fasta
        mv tmp.$id.fasta $id.fasta
        cd ..
        rm OUT$slot/*.out
    fi
done
